from django_upgrade.main import main

if __name__ == "__main__":  # pragma: no cover
    raise SystemExit(main())
